/* A Bison parser, made by GNU Bison 3.0.4.  */

/* Bison implementation for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* C LALR(1) parser skeleton written by Richard Stallman, by
   simplifying the original so-called "semantic" parser.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output.  */
#define YYBISON 1

/* Bison version.  */
#define YYBISON_VERSION "3.0.4"

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 0

/* Push parsers.  */
#define YYPUSH 0

/* Pull parsers.  */
#define YYPULL 1




/* Copy the first part of user declarations.  */
#line 1 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:339  */

/*
 * Copyright (C) 1994-2000 The XFree86 Project, Inc. All Rights Reserved.
 * Copyright (C) Colin Harrison 2005-2008
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE XFREE86 PROJECT BE LIABLE FOR
 * ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
 * CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 * Except as contained in this notice, the name of the XFree86 Project
 * shall not be used in advertising or otherwise to promote the sale, use
 * or other dealings in this Software without prior written authorization
 * from the XFree86 Project.
 *
 * Authors:     Earle F. Philhower, III
 *              Colin Harrison
 */
/* $XFree86: $ */

#ifdef HAVE_XWIN_CONFIG_H
#include <xwin-config.h>
#endif
#include <stdio.h>
#include <stdlib.h>
#define _STDLIB_H 1 /* bison checks this to know if stdlib has been included */
#include <string.h>
#include "globals.h"
#include "winconfig.h"
#include "winprefs.h"

/* The following give better error messages in bison at the cost of a few KB */
#define YYERROR_VERBOSE 1

/* YYLTYPE_IS_TRIVIAL and YYENABLE_NLS defined to suppress warnings */
#define YYLTYPE_IS_TRIVIAL 1
#define YYENABLE_NLS 0

/* The global pref settings */
WINPREFS pref;

/* The working menu */  
static MENUPARSED menu;

/* Functions for parsing the tokens into out structure */
/* Defined at the end section of this file */

static void SetDPI (char *dpi);
static void SetXKBLayout (char *layout);
static void SetXKBModel (char *model);
static void SetXKBOptions (char *options);
static void SetXKBRules (char *rules);
static void SetXKBVariant (char *variant);

static void SetIconDirectory (char *path);
static void SetDefaultIcon (char *fname);
static void SetRootMenu (char *menu);
static void SetDefaultSysMenu (char *menu, int pos);
static void SetTrayIcon (char *fname);

static void OpenMenu(char *menuname);
static void AddMenuLine(const char *name, MENUCOMMANDTYPE cmd, const char *param);
static void CloseMenu(void);

static void OpenIcons(void);
static void AddIconLine(char *matchstr, char *iconfile);
static void CloseIcons(void);

static void OpenStyles(void);
static void AddStyleLine(char *matchstr, unsigned long style);
static void CloseStyles(void);

static void OpenSysMenu(void);
static void AddSysMenuLine(char *matchstr, char *menuname, int pos);
static void CloseSysMenu(void);

static int yyerror (const char *s);

extern char *yytext;
extern int yylineno;
extern int yylex(void);


#line 164 "winprefsyacc.c" /* yacc.c:339  */

# ifndef YY_NULLPTR
#  if defined __cplusplus && 201103L <= __cplusplus
#   define YY_NULLPTR nullptr
#  else
#   define YY_NULLPTR 0
#  endif
# endif

/* Enabling verbose error messages.  */
#ifdef YYERROR_VERBOSE
# undef YYERROR_VERBOSE
# define YYERROR_VERBOSE 1
#else
# define YYERROR_VERBOSE 0
#endif

/* In a future release of Bison, this section will be replaced
   by #include "y.tab.h".  */
#ifndef YY_YY_WINPREFSYACC_H_INCLUDED
# define YY_YY_WINPREFSYACC_H_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int yydebug;
#endif

/* Token type.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    NEWLINE = 258,
    MENU = 259,
    LB = 260,
    RB = 261,
    ICONDIRECTORY = 262,
    DEFAULTICON = 263,
    ICONS = 264,
    STYLES = 265,
    TOPMOST = 266,
    MAXIMIZE = 267,
    MINIMIZE = 268,
    BOTTOM = 269,
    NOTITLE = 270,
    OUTLINE = 271,
    NOFRAME = 272,
    SKIPTASKBAR = 273,
    DEFAULTSYSMENU = 274,
    SYSMENU = 275,
    ROOTMENU = 276,
    SEPARATOR = 277,
    ATSTART = 278,
    ATEND = 279,
    EXEC = 280,
    ALWAYSONTOP = 281,
    DEBUGOUTPUT = 282,
    RELOAD = 283,
    TRAYICON = 284,
    FORCEEXIT = 285,
    SILENTEXIT = 286,
    DPI = 287,
    XKBLAYOUT = 288,
    XKBMODEL = 289,
    XKBOPTIONS = 290,
    XKBRULES = 291,
    XKBVARIANT = 292,
    STRING = 293
  };
#endif
/* Tokens.  */
#define NEWLINE 258
#define MENU 259
#define LB 260
#define RB 261
#define ICONDIRECTORY 262
#define DEFAULTICON 263
#define ICONS 264
#define STYLES 265
#define TOPMOST 266
#define MAXIMIZE 267
#define MINIMIZE 268
#define BOTTOM 269
#define NOTITLE 270
#define OUTLINE 271
#define NOFRAME 272
#define SKIPTASKBAR 273
#define DEFAULTSYSMENU 274
#define SYSMENU 275
#define ROOTMENU 276
#define SEPARATOR 277
#define ATSTART 278
#define ATEND 279
#define EXEC 280
#define ALWAYSONTOP 281
#define DEBUGOUTPUT 282
#define RELOAD 283
#define TRAYICON 284
#define FORCEEXIT 285
#define SILENTEXIT 286
#define DPI 287
#define XKBLAYOUT 288
#define XKBMODEL 289
#define XKBOPTIONS 290
#define XKBRULES 291
#define XKBVARIANT 292
#define STRING 293

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED

union YYSTYPE
{
#line 99 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:355  */

  char *sVal;
  unsigned long uVal;
  int iVal;

#line 286 "winprefsyacc.c" /* yacc.c:355  */
};

typedef union YYSTYPE YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif


extern YYSTYPE yylval;

int yyparse (void);

#endif /* !YY_YY_WINPREFSYACC_H_INCLUDED  */

/* Copy the second part of user declarations.  */

#line 303 "winprefsyacc.c" /* yacc.c:358  */

#ifdef short
# undef short
#endif

#ifdef YYTYPE_UINT8
typedef YYTYPE_UINT8 yytype_uint8;
#else
typedef unsigned char yytype_uint8;
#endif

#ifdef YYTYPE_INT8
typedef YYTYPE_INT8 yytype_int8;
#else
typedef signed char yytype_int8;
#endif

#ifdef YYTYPE_UINT16
typedef YYTYPE_UINT16 yytype_uint16;
#else
typedef unsigned short int yytype_uint16;
#endif

#ifdef YYTYPE_INT16
typedef YYTYPE_INT16 yytype_int16;
#else
typedef short int yytype_int16;
#endif

#ifndef YYSIZE_T
# ifdef __SIZE_TYPE__
#  define YYSIZE_T __SIZE_TYPE__
# elif defined size_t
#  define YYSIZE_T size_t
# elif ! defined YYSIZE_T
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# else
#  define YYSIZE_T unsigned int
# endif
#endif

#define YYSIZE_MAXIMUM ((YYSIZE_T) -1)

#ifndef YY_
# if defined YYENABLE_NLS && YYENABLE_NLS
#  if ENABLE_NLS
#   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
#  endif
# endif
# ifndef YY_
#  define YY_(Msgid) Msgid
# endif
#endif

#ifndef YY_ATTRIBUTE
# if (defined __GNUC__                                               \
      && (2 < __GNUC__ || (__GNUC__ == 2 && 96 <= __GNUC_MINOR__)))  \
     || defined __SUNPRO_C && 0x5110 <= __SUNPRO_C
#  define YY_ATTRIBUTE(Spec) __attribute__(Spec)
# else
#  define YY_ATTRIBUTE(Spec) /* empty */
# endif
#endif

#ifndef YY_ATTRIBUTE_PURE
# define YY_ATTRIBUTE_PURE   YY_ATTRIBUTE ((__pure__))
#endif

#ifndef YY_ATTRIBUTE_UNUSED
# define YY_ATTRIBUTE_UNUSED YY_ATTRIBUTE ((__unused__))
#endif

#if !defined _Noreturn \
     && (!defined __STDC_VERSION__ || __STDC_VERSION__ < 201112)
# if defined _MSC_VER && 1200 <= _MSC_VER
#  define _Noreturn __declspec (noreturn)
# else
#  define _Noreturn YY_ATTRIBUTE ((__noreturn__))
# endif
#endif

/* Suppress unused-variable warnings by "using" E.  */
#if ! defined lint || defined __GNUC__
# define YYUSE(E) ((void) (E))
#else
# define YYUSE(E) /* empty */
#endif

#if defined __GNUC__ && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
/* Suppress an incorrect diagnostic about yylval being uninitialized.  */
# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
    _Pragma ("GCC diagnostic push") \
    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")\
    _Pragma ("GCC diagnostic ignored \"-Wmaybe-uninitialized\"")
# define YY_IGNORE_MAYBE_UNINITIALIZED_END \
    _Pragma ("GCC diagnostic pop")
#else
# define YY_INITIAL_VALUE(Value) Value
#endif
#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_END
#endif
#ifndef YY_INITIAL_VALUE
# define YY_INITIAL_VALUE(Value) /* Nothing. */
#endif


#if ! defined yyoverflow || YYERROR_VERBOSE

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# ifdef YYSTACK_USE_ALLOCA
#  if YYSTACK_USE_ALLOCA
#   ifdef __GNUC__
#    define YYSTACK_ALLOC __builtin_alloca
#   elif defined __BUILTIN_VA_ARG_INCR
#    include <alloca.h> /* INFRINGES ON USER NAME SPACE */
#   elif defined _AIX
#    define YYSTACK_ALLOC __alloca
#   elif defined _MSC_VER
#    include <malloc.h> /* INFRINGES ON USER NAME SPACE */
#    define alloca _alloca
#   else
#    define YYSTACK_ALLOC alloca
#    if ! defined _ALLOCA_H && ! defined EXIT_SUCCESS
#     include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
      /* Use EXIT_SUCCESS as a witness for stdlib.h.  */
#     ifndef EXIT_SUCCESS
#      define EXIT_SUCCESS 0
#     endif
#    endif
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's 'empty if-body' warning.  */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
#  ifndef YYSTACK_ALLOC_MAXIMUM
    /* The OS might guarantee only one guard page at the bottom of the stack,
       and a page size can be as small as 4096 bytes.  So we cannot safely
       invoke alloca (N) if N exceeds 4096.  Use a slightly smaller number
       to allow for a few compiler-allocated temporary stack slots.  */
#   define YYSTACK_ALLOC_MAXIMUM 4032 /* reasonable circa 2006 */
#  endif
# else
#  define YYSTACK_ALLOC YYMALLOC
#  define YYSTACK_FREE YYFREE
#  ifndef YYSTACK_ALLOC_MAXIMUM
#   define YYSTACK_ALLOC_MAXIMUM YYSIZE_MAXIMUM
#  endif
#  if (defined __cplusplus && ! defined EXIT_SUCCESS \
       && ! ((defined YYMALLOC || defined malloc) \
             && (defined YYFREE || defined free)))
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   ifndef EXIT_SUCCESS
#    define EXIT_SUCCESS 0
#   endif
#  endif
#  ifndef YYMALLOC
#   define YYMALLOC malloc
#   if ! defined malloc && ! defined EXIT_SUCCESS
void *malloc (YYSIZE_T); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
#  ifndef YYFREE
#   define YYFREE free
#   if ! defined free && ! defined EXIT_SUCCESS
void free (void *); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
# endif
#endif /* ! defined yyoverflow || YYERROR_VERBOSE */


#if (! defined yyoverflow \
     && (! defined __cplusplus \
         || (defined YYSTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  yytype_int16 yyss_alloc;
  YYSTYPE yyvs_alloc;
};

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (sizeof (yytype_int16) + sizeof (YYSTYPE)) \
      + YYSTACK_GAP_MAXIMUM)

# define YYCOPY_NEEDED 1

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack_alloc, Stack)                           \
    do                                                                  \
      {                                                                 \
        YYSIZE_T yynewbytes;                                            \
        YYCOPY (&yyptr->Stack_alloc, Stack, yysize);                    \
        Stack = &yyptr->Stack_alloc;                                    \
        yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
        yyptr += yynewbytes / sizeof (*yyptr);                          \
      }                                                                 \
    while (0)

#endif

#if defined YYCOPY_NEEDED && YYCOPY_NEEDED
/* Copy COUNT objects from SRC to DST.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if defined __GNUC__ && 1 < __GNUC__
#   define YYCOPY(Dst, Src, Count) \
      __builtin_memcpy (Dst, Src, (Count) * sizeof (*(Src)))
#  else
#   define YYCOPY(Dst, Src, Count)              \
      do                                        \
        {                                       \
          YYSIZE_T yyi;                         \
          for (yyi = 0; yyi < (Count); yyi++)   \
            (Dst)[yyi] = (Src)[yyi];            \
        }                                       \
      while (0)
#  endif
# endif
#endif /* !YYCOPY_NEEDED */

/* YYFINAL -- State number of the termination state.  */
#define YYFINAL  2
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   140

/* YYNTOKENS -- Number of terminals.  */
#define YYNTOKENS  39
/* YYNNTS -- Number of nonterminals.  */
#define YYNNTS  40
/* YYNRULES -- Number of rules.  */
#define YYNRULES  89
/* YYNSTATES -- Number of states.  */
#define YYNSTATES  157

/* YYTRANSLATE[YYX] -- Symbol number corresponding to YYX as returned
   by yylex, with out-of-bounds checking.  */
#define YYUNDEFTOK  2
#define YYMAXUTOK   293

#define YYTRANSLATE(YYX)                                                \
  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)

/* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
   as returned by yylex, without out-of-bounds checking.  */
static const yytype_uint8 yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
      35,    36,    37,    38
};

#if YYDEBUG
  /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
static const yytype_uint16 yyrline[] =
{
       0,   150,   150,   151,   154,   155,   159,   160,   163,   164,
     165,   166,   167,   168,   169,   170,   171,   172,   173,   174,
     175,   176,   177,   178,   179,   180,   183,   186,   189,   192,
     195,   198,   201,   204,   207,   210,   213,   216,   217,   218,
     219,   220,   223,   224,   227,   227,   230,   233,   234,   237,
     237,   240,   241,   242,   243,   246,   247,   248,   251,   254,
     255,   256,   257,   258,   259,   260,   261,   262,   263,   264,
     265,   266,   267,   268,   271,   274,   275,   278,   278,   281,
     282,   283,   286,   289,   290,   293,   293,   296,   299,   302
};
#endif

#if YYDEBUG || YYERROR_VERBOSE || 0
/* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
static const char *const yytname[] =
{
  "$end", "error", "$undefined", "NEWLINE", "MENU", "LB", "RB",
  "ICONDIRECTORY", "DEFAULTICON", "ICONS", "STYLES", "TOPMOST", "MAXIMIZE",
  "MINIMIZE", "BOTTOM", "NOTITLE", "OUTLINE", "NOFRAME", "SKIPTASKBAR",
  "DEFAULTSYSMENU", "SYSMENU", "ROOTMENU", "SEPARATOR", "ATSTART", "ATEND",
  "EXEC", "ALWAYSONTOP", "\"DEBUG\"", "RELOAD", "TRAYICON", "FORCEEXIT",
  "SILENTEXIT", "DPI", "XKBLAYOUT", "XKBMODEL", "XKBOPTIONS", "XKBRULES",
  "XKBVARIANT", "STRING", "$accept", "input", "line", "newline_or_nada",
  "command", "dpi", "xkblayout", "xkbmodel", "xkboptions", "xkbrules",
  "xkbvariant", "trayicon", "rootmenu", "defaultsysmenu", "defaulticon",
  "icondirectory", "menuline", "menulist", "menu", "$@1", "iconline",
  "iconlist", "icons", "$@2", "group1", "group2", "group3", "stylecombo",
  "styleline", "stylelist", "styles", "$@3", "atspot", "sysmenuline",
  "sysmenulist", "sysmenu", "$@4", "forceexit", "silentexit", "debug", YY_NULLPTR
};
#endif

# ifdef YYPRINT
/* YYTOKNUM[NUM] -- (External) token number corresponding to the
   (internal) symbol number NUM (which must be that of a token).  */
static const yytype_uint16 yytoknum[] =
{
       0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
     265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
     275,   276,   277,   278,   279,   280,   281,   282,   283,   284,
     285,   286,   287,   288,   289,   290,   291,   292,   293
};
# endif

#define YYPACT_NINF -104

#define yypact_value_is_default(Yystate) \
  (!!((Yystate) == (-104)))

#define YYTABLE_NINF -1

#define yytable_value_is_error(Yytable_value) \
  0

  /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
     STATE-NUM.  */
static const yytype_int16 yypact[] =
{
    -104,     1,  -104,  -104,   -35,   -26,   -20,    34,    38,     3,
      39,    13,    14,    21,    60,    62,    28,    35,    46,    49,
      50,    63,  -104,  -104,  -104,  -104,  -104,  -104,  -104,  -104,
    -104,  -104,  -104,  -104,  -104,  -104,  -104,  -104,  -104,  -104,
    -104,  -104,    67,    99,   100,  -104,  -104,    -7,   101,   102,
     103,   104,  -104,  -104,   105,   106,   107,   108,   109,   110,
    -104,  -104,  -104,   111,   111,  -104,  -104,   112,  -104,  -104,
    -104,  -104,  -104,  -104,  -104,  -104,  -104,  -104,   111,   111,
      78,    80,  -104,   111,    -9,  -104,    81,    78,   114,    65,
      80,   115,    84,   120,    -2,    -9,   118,   122,  -104,  -104,
    -104,  -104,  -104,  -104,  -104,  -104,  -104,  -104,    53,    36,
      79,   123,  -104,  -104,    89,    84,   124,   111,    90,    91,
     128,   129,  -104,  -104,   111,   116,    40,   116,    86,    40,
      86,   111,    -7,  -104,  -104,  -104,   130,   132,   111,   111,
    -104,  -104,  -104,  -104,  -104,  -104,  -104,  -104,   133,   111,
     111,  -104,  -104,   111,  -104,  -104,  -104
};

  /* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
     Performed when YYTABLE does not specify something else to do.  Zero
     means the default is an error.  */
static const yytype_uint8 yydefact[] =
{
       2,     0,     1,     4,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     3,     5,    20,    21,    22,    23,    24,    25,
      17,    14,    15,     8,     9,    10,    11,    12,    13,    18,
      19,    16,     0,     0,     0,    49,    77,    79,     0,     0,
       0,     0,    87,    88,     0,     0,     0,     0,     0,     0,
      44,    36,    35,     6,     6,    80,    81,     0,    85,    33,
      89,    32,    26,    27,    28,    29,    30,    31,     6,     6,
       0,     0,    34,     6,     0,     7,     0,    47,     0,     0,
      75,     0,     0,     0,     0,    42,     0,     0,    48,    50,
      51,    52,    53,    54,    55,    56,    57,    58,    59,    60,
      61,     0,    76,    78,     0,    83,     0,     6,     0,     0,
       0,     0,    43,    45,     6,    62,    63,    64,    65,    66,
      67,     6,    79,    84,    86,    37,     0,     0,     6,     6,
      46,    68,    69,    70,    71,    72,    73,    74,     0,     6,
       6,    38,    41,     6,    40,    39,    82
};

  /* YYPGOTO[NTERM-NUM].  */
static const yytype_int8 yypgoto[] =
{
    -104,  -104,  -104,   -64,  -104,  -104,  -104,  -104,  -104,  -104,
    -104,  -104,  -104,  -104,  -104,  -104,  -104,    22,  -104,  -104,
    -104,    51,  -104,  -104,  -103,   -68,   -63,  -104,  -104,    47,
    -104,  -104,     7,  -104,    25,  -104,  -104,  -104,  -104,  -104
};

  /* YYDEFGOTO[NTERM-NUM].  */
static const yytype_int8 yydefgoto[] =
{
      -1,     1,    22,    80,    23,    24,    25,    26,    27,    28,
      29,    30,    31,    32,    33,    34,    95,    96,    35,    78,
      87,    88,    36,    63,   108,   109,   110,   111,    90,    91,
      37,    64,    67,   115,   116,    38,    83,    39,    40,    41
};

  /* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
     positive, shift that token.  If negative, reduce the rule whose
     number is the opposite.  If YYTABLE_NINF, syntax error.  */
static const yytype_uint8 yytable[] =
{
      81,     2,   118,    42,     3,     4,   127,   129,     5,     6,
       7,     8,    43,    93,    84,    85,    65,    66,    44,    92,
       9,    10,    11,   119,   120,   144,   121,   146,    12,    94,
      13,    14,    15,    16,    17,    18,    19,    20,    21,    45,
     125,    47,   130,    46,    48,   126,   128,   100,   101,   102,
     103,    49,    50,   135,   107,   104,   105,   106,   142,    51,
     140,   145,   141,    52,   143,    53,    54,   147,   104,   105,
     106,   107,    60,    55,   151,   152,   100,   101,   102,   103,
     104,   105,   106,   107,    56,   154,   155,    57,    58,   156,
     100,   101,   102,   103,   104,   105,   106,   100,   101,   102,
     103,    59,    61,    62,    68,    69,    70,    71,    72,    73,
      74,    75,    76,    77,    79,    82,    86,   122,    89,    97,
      99,   113,   114,   117,   123,   124,   131,   132,   136,   137,
     134,   138,   139,   149,   107,   150,   153,   112,    98,   148,
     133
};

static const yytype_uint8 yycheck[] =
{
      64,     0,     4,    38,     3,     4,   109,   110,     7,     8,
       9,    10,    38,    22,    78,    79,    23,    24,    38,    83,
      19,    20,    21,    25,    26,   128,    28,   130,    27,    38,
      29,    30,    31,    32,    33,    34,    35,    36,    37,     5,
     108,    38,   110,     5,     5,   108,   109,    11,    12,    13,
      14,    38,    38,   117,    18,    15,    16,    17,   126,    38,
     124,   129,   125,     3,   127,     3,    38,   131,    15,    16,
      17,    18,     5,    38,   138,   139,    11,    12,    13,    14,
      15,    16,    17,    18,    38,   149,   150,    38,    38,   153,
      11,    12,    13,    14,    15,    16,    17,    11,    12,    13,
      14,    38,     3,     3,     3,     3,     3,     3,     3,     3,
       3,     3,     3,     3,     3,     3,    38,    95,    38,    38,
       6,     6,    38,     3,     6,     3,     3,    38,    38,    38,
       6,     3,     3,     3,    18,     3,     3,    90,    87,   132,
     115
};

  /* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
     symbol of state STATE-NUM.  */
static const yytype_uint8 yystos[] =
{
       0,    40,     0,     3,     4,     7,     8,     9,    10,    19,
      20,    21,    27,    29,    30,    31,    32,    33,    34,    35,
      36,    37,    41,    43,    44,    45,    46,    47,    48,    49,
      50,    51,    52,    53,    54,    57,    61,    69,    74,    76,
      77,    78,    38,    38,    38,     5,     5,    38,     5,    38,
      38,    38,     3,     3,    38,    38,    38,    38,    38,    38,
       5,     3,     3,    62,    70,    23,    24,    71,     3,     3,
       3,     3,     3,     3,     3,     3,     3,     3,    58,     3,
      42,    42,     3,    75,    42,    42,    38,    59,    60,    38,
      67,    68,    42,    22,    38,    55,    56,    38,    60,     6,
      11,    12,    13,    14,    15,    16,    17,    18,    63,    64,
      65,    66,    68,     6,    38,    72,    73,     3,     4,    25,
      26,    28,    56,     6,     3,    64,    65,    63,    65,    63,
      64,     3,    38,    73,     6,    42,    38,    38,     3,     3,
      42,    65,    64,    65,    63,    64,    63,    42,    71,     3,
       3,    42,    42,     3,    42,    42,    42
};

  /* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
static const yytype_uint8 yyr1[] =
{
       0,    39,    40,    40,    41,    41,    42,    42,    43,    43,
      43,    43,    43,    43,    43,    43,    43,    43,    43,    43,
      43,    43,    43,    43,    43,    43,    44,    45,    46,    47,
      48,    49,    50,    51,    52,    53,    54,    55,    55,    55,
      55,    55,    56,    56,    58,    57,    59,    60,    60,    62,
      61,    63,    63,    63,    63,    64,    64,    64,    65,    66,
      66,    66,    66,    66,    66,    66,    66,    66,    66,    66,
      66,    66,    66,    66,    67,    68,    68,    70,    69,    71,
      71,    71,    72,    73,    73,    75,    74,    76,    77,    78
};

  /* YYR2[YYN] -- Number of symbols on the right hand side of rule YYN.  */
static const yytype_uint8 yyr2[] =
{
       0,     2,     0,     2,     1,     1,     0,     2,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     3,     3,     3,     3,
       3,     3,     3,     3,     4,     3,     3,     3,     4,     5,
       5,     4,     1,     2,     0,     7,     4,     1,     2,     0,
       6,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     2,     2,     2,     2,     2,     2,     3,     3,
       3,     3,     3,     3,     4,     1,     2,     0,     6,     0,
       1,     1,     5,     1,     2,     0,     7,     2,     2,     3
};


#define yyerrok         (yyerrstatus = 0)
#define yyclearin       (yychar = YYEMPTY)
#define YYEMPTY         (-2)
#define YYEOF           0

#define YYACCEPT        goto yyacceptlab
#define YYABORT         goto yyabortlab
#define YYERROR         goto yyerrorlab


#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)                                  \
do                                                              \
  if (yychar == YYEMPTY)                                        \
    {                                                           \
      yychar = (Token);                                         \
      yylval = (Value);                                         \
      YYPOPSTACK (yylen);                                       \
      yystate = *yyssp;                                         \
      goto yybackup;                                            \
    }                                                           \
  else                                                          \
    {                                                           \
      yyerror (YY_("syntax error: cannot back up")); \
      YYERROR;                                                  \
    }                                                           \
while (0)

/* Error token number */
#define YYTERROR        1
#define YYERRCODE       256



/* Enable debugging if requested.  */
#if YYDEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)                        \
do {                                            \
  if (yydebug)                                  \
    YYFPRINTF Args;                             \
} while (0)

/* This macro is provided for backward compatibility. */
#ifndef YY_LOCATION_PRINT
# define YY_LOCATION_PRINT(File, Loc) ((void) 0)
#endif


# define YY_SYMBOL_PRINT(Title, Type, Value, Location)                    \
do {                                                                      \
  if (yydebug)                                                            \
    {                                                                     \
      YYFPRINTF (stderr, "%s ", Title);                                   \
      yy_symbol_print (stderr,                                            \
                  Type, Value); \
      YYFPRINTF (stderr, "\n");                                           \
    }                                                                     \
} while (0)


/*----------------------------------------.
| Print this symbol's value on YYOUTPUT.  |
`----------------------------------------*/

static void
yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
{
  FILE *yyo = yyoutput;
  YYUSE (yyo);
  if (!yyvaluep)
    return;
# ifdef YYPRINT
  if (yytype < YYNTOKENS)
    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
# endif
  YYUSE (yytype);
}


/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

static void
yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
{
  YYFPRINTF (yyoutput, "%s %s (",
             yytype < YYNTOKENS ? "token" : "nterm", yytname[yytype]);

  yy_symbol_value_print (yyoutput, yytype, yyvaluep);
  YYFPRINTF (yyoutput, ")");
}

/*------------------------------------------------------------------.
| yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (included).                                                   |
`------------------------------------------------------------------*/

static void
yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
{
  YYFPRINTF (stderr, "Stack now");
  for (; yybottom <= yytop; yybottom++)
    {
      int yybot = *yybottom;
      YYFPRINTF (stderr, " %d", yybot);
    }
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)                            \
do {                                                            \
  if (yydebug)                                                  \
    yy_stack_print ((Bottom), (Top));                           \
} while (0)


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

static void
yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule)
{
  unsigned long int yylno = yyrline[yyrule];
  int yynrhs = yyr2[yyrule];
  int yyi;
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
             yyrule - 1, yylno);
  /* The symbols being reduced.  */
  for (yyi = 0; yyi < yynrhs; yyi++)
    {
      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
      yy_symbol_print (stderr,
                       yystos[yyssp[yyi + 1 - yynrhs]],
                       &(yyvsp[(yyi + 1) - (yynrhs)])
                                              );
      YYFPRINTF (stderr, "\n");
    }
}

# define YY_REDUCE_PRINT(Rule)          \
do {                                    \
  if (yydebug)                          \
    yy_reduce_print (yyssp, yyvsp, Rule); \
} while (0)

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !YYDEBUG */
# define YYDPRINTF(Args)
# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !YYDEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   YYSTACK_ALLOC_MAXIMUM < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif


#if YYERROR_VERBOSE

# ifndef yystrlen
#  if defined __GLIBC__ && defined _STRING_H
#   define yystrlen strlen
#  else
/* Return the length of YYSTR.  */
static YYSIZE_T
yystrlen (const char *yystr)
{
  YYSIZE_T yylen;
  for (yylen = 0; yystr[yylen]; yylen++)
    continue;
  return yylen;
}
#  endif
# endif

# ifndef yystpcpy
#  if defined __GLIBC__ && defined _STRING_H && defined _GNU_SOURCE
#   define yystpcpy stpcpy
#  else
/* Copy YYSRC to YYDEST, returning the address of the terminating '\0' in
   YYDEST.  */
static char *
yystpcpy (char *yydest, const char *yysrc)
{
  char *yyd = yydest;
  const char *yys = yysrc;

  while ((*yyd++ = *yys++) != '\0')
    continue;

  return yyd - 1;
}
#  endif
# endif

# ifndef yytnamerr
/* Copy to YYRES the contents of YYSTR after stripping away unnecessary
   quotes and backslashes, so that it's suitable for yyerror.  The
   heuristic is that double-quoting is unnecessary unless the string
   contains an apostrophe, a comma, or backslash (other than
   backslash-backslash).  YYSTR is taken from yytname.  If YYRES is
   null, do not copy; instead, return the length of what the result
   would have been.  */
static YYSIZE_T
yytnamerr (char *yyres, const char *yystr)
{
  if (*yystr == '"')
    {
      YYSIZE_T yyn = 0;
      char const *yyp = yystr;

      for (;;)
        switch (*++yyp)
          {
          case '\'':
          case ',':
            goto do_not_strip_quotes;

          case '\\':
            if (*++yyp != '\\')
              goto do_not_strip_quotes;
            /* Fall through.  */
          default:
            if (yyres)
              yyres[yyn] = *yyp;
            yyn++;
            break;

          case '"':
            if (yyres)
              yyres[yyn] = '\0';
            return yyn;
          }
    do_not_strip_quotes: ;
    }

  if (! yyres)
    return yystrlen (yystr);

  return yystpcpy (yyres, yystr) - yyres;
}
# endif

/* Copy into *YYMSG, which is of size *YYMSG_ALLOC, an error message
   about the unexpected token YYTOKEN for the state stack whose top is
   YYSSP.

   Return 0 if *YYMSG was successfully written.  Return 1 if *YYMSG is
   not large enough to hold the message.  In that case, also set
   *YYMSG_ALLOC to the required number of bytes.  Return 2 if the
   required number of bytes is too large to store.  */
static int
yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                yytype_int16 *yyssp, int yytoken)
{
  YYSIZE_T yysize0 = yytnamerr (YY_NULLPTR, yytname[yytoken]);
  YYSIZE_T yysize = yysize0;
  enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
  /* Internationalized format string. */
  const char *yyformat = YY_NULLPTR;
  /* Arguments of yyformat. */
  char const *yyarg[YYERROR_VERBOSE_ARGS_MAXIMUM];
  /* Number of reported tokens (one for the "unexpected", one per
     "expected"). */
  int yycount = 0;

  /* There are many possibilities here to consider:
     - If this state is a consistent state with a default action, then
       the only way this function was invoked is if the default action
       is an error action.  In that case, don't check for expected
       tokens because there are none.
     - The only way there can be no lookahead present (in yychar) is if
       this state is a consistent state with a default action.  Thus,
       detecting the absence of a lookahead is sufficient to determine
       that there is no unexpected or expected token to report.  In that
       case, just report a simple "syntax error".
     - Don't assume there isn't a lookahead just because this state is a
       consistent state with a default action.  There might have been a
       previous inconsistent state, consistent state with a non-default
       action, or user semantic action that manipulated yychar.
     - Of course, the expected token list depends on states to have
       correct lookahead information, and it depends on the parser not
       to perform extra reductions after fetching a lookahead from the
       scanner and before detecting a syntax error.  Thus, state merging
       (from LALR or IELR) and default reductions corrupt the expected
       token list.  However, the list is correct for canonical LR with
       one exception: it will still contain any token that will not be
       accepted due to an error action in a later state.
  */
  if (yytoken != YYEMPTY)
    {
      int yyn = yypact[*yyssp];
      yyarg[yycount++] = yytname[yytoken];
      if (!yypact_value_is_default (yyn))
        {
          /* Start YYX at -YYN if negative to avoid negative indexes in
             YYCHECK.  In other words, skip the first -YYN actions for
             this state because they are default actions.  */
          int yyxbegin = yyn < 0 ? -yyn : 0;
          /* Stay within bounds of both yycheck and yytname.  */
          int yychecklim = YYLAST - yyn + 1;
          int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
          int yyx;

          for (yyx = yyxbegin; yyx < yyxend; ++yyx)
            if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR
                && !yytable_value_is_error (yytable[yyx + yyn]))
              {
                if (yycount == YYERROR_VERBOSE_ARGS_MAXIMUM)
                  {
                    yycount = 1;
                    yysize = yysize0;
                    break;
                  }
                yyarg[yycount++] = yytname[yyx];
                {
                  YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULLPTR, yytname[yyx]);
                  if (! (yysize <= yysize1
                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
                    return 2;
                  yysize = yysize1;
                }
              }
        }
    }

  switch (yycount)
    {
# define YYCASE_(N, S)                      \
      case N:                               \
        yyformat = S;                       \
      break
      YYCASE_(0, YY_("syntax error"));
      YYCASE_(1, YY_("syntax error, unexpected %s"));
      YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
      YYCASE_(3, YY_("syntax error, unexpected %s, expecting %s or %s"));
      YYCASE_(4, YY_("syntax error, unexpected %s, expecting %s or %s or %s"));
      YYCASE_(5, YY_("syntax error, unexpected %s, expecting %s or %s or %s or %s"));
# undef YYCASE_
    }

  {
    YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
      return 2;
    yysize = yysize1;
  }

  if (*yymsg_alloc < yysize)
    {
      *yymsg_alloc = 2 * yysize;
      if (! (yysize <= *yymsg_alloc
             && *yymsg_alloc <= YYSTACK_ALLOC_MAXIMUM))
        *yymsg_alloc = YYSTACK_ALLOC_MAXIMUM;
      return 1;
    }

  /* Avoid sprintf, as that infringes on the user's name space.
     Don't have undefined behavior even if the translation
     produced a string with the wrong number of "%s"s.  */
  {
    char *yyp = *yymsg;
    int yyi = 0;
    while ((*yyp = *yyformat) != '\0')
      if (*yyp == '%' && yyformat[1] == 's' && yyi < yycount)
        {
          yyp += yytnamerr (yyp, yyarg[yyi++]);
          yyformat += 2;
        }
      else
        {
          yyp++;
          yyformat++;
        }
  }
  return 0;
}
#endif /* YYERROR_VERBOSE */

/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

static void
yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep)
{
  YYUSE (yyvaluep);
  if (!yymsg)
    yymsg = "Deleting";
  YY_SYMBOL_PRINT (yymsg, yytype, yyvaluep, yylocationp);

  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  YYUSE (yytype);
  YY_IGNORE_MAYBE_UNINITIALIZED_END
}




/* The lookahead symbol.  */
int yychar;

/* The semantic value of the lookahead symbol.  */
YYSTYPE yylval;
/* Number of syntax errors so far.  */
int yynerrs;


/*----------.
| yyparse.  |
`----------*/

int
yyparse (void)
{
    int yystate;
    /* Number of tokens to shift before error messages enabled.  */
    int yyerrstatus;

    /* The stacks and their tools:
       'yyss': related to states.
       'yyvs': related to semantic values.

       Refer to the stacks through separate pointers, to allow yyoverflow
       to reallocate them elsewhere.  */

    /* The state stack.  */
    yytype_int16 yyssa[YYINITDEPTH];
    yytype_int16 *yyss;
    yytype_int16 *yyssp;

    /* The semantic value stack.  */
    YYSTYPE yyvsa[YYINITDEPTH];
    YYSTYPE *yyvs;
    YYSTYPE *yyvsp;

    YYSIZE_T yystacksize;

  int yyn;
  int yyresult;
  /* Lookahead token as an internal (translated) token number.  */
  int yytoken = 0;
  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;

#if YYERROR_VERBOSE
  /* Buffer for error messages, and its allocated size.  */
  char yymsgbuf[128];
  char *yymsg = yymsgbuf;
  YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
#endif

#define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))

  /* The number of symbols on the RHS of the reduced rule.
     Keep to zero when no symbol should be popped.  */
  int yylen = 0;

  yyssp = yyss = yyssa;
  yyvsp = yyvs = yyvsa;
  yystacksize = YYINITDEPTH;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yystate = 0;
  yyerrstatus = 0;
  yynerrs = 0;
  yychar = YYEMPTY; /* Cause a token to be read.  */
  goto yysetstate;

/*------------------------------------------------------------.
| yynewstate -- Push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
 yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed.  So pushing a state here evens the stacks.  */
  yyssp++;

 yysetstate:
  *yyssp = yystate;

  if (yyss + yystacksize - 1 <= yyssp)
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYSIZE_T yysize = yyssp - yyss + 1;

#ifdef yyoverflow
      {
        /* Give user a chance to reallocate the stack.  Use copies of
           these so that the &'s don't force the real ones into
           memory.  */
        YYSTYPE *yyvs1 = yyvs;
        yytype_int16 *yyss1 = yyss;

        /* Each stack pointer address is followed by the size of the
           data in use in that stack, in bytes.  This used to be a
           conditional around just the two extra args, but that might
           be undefined if yyoverflow is a macro.  */
        yyoverflow (YY_("memory exhausted"),
                    &yyss1, yysize * sizeof (*yyssp),
                    &yyvs1, yysize * sizeof (*yyvsp),
                    &yystacksize);

        yyss = yyss1;
        yyvs = yyvs1;
      }
#else /* no yyoverflow */
# ifndef YYSTACK_RELOCATE
      goto yyexhaustedlab;
# else
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= yystacksize)
        goto yyexhaustedlab;
      yystacksize *= 2;
      if (YYMAXDEPTH < yystacksize)
        yystacksize = YYMAXDEPTH;

      {
        yytype_int16 *yyss1 = yyss;
        union yyalloc *yyptr =
          (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
        if (! yyptr)
          goto yyexhaustedlab;
        YYSTACK_RELOCATE (yyss_alloc, yyss);
        YYSTACK_RELOCATE (yyvs_alloc, yyvs);
#  undef YYSTACK_RELOCATE
        if (yyss1 != yyssa)
          YYSTACK_FREE (yyss1);
      }
# endif
#endif /* no yyoverflow */

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;

      YYDPRINTF ((stderr, "Stack size increased to %lu\n",
                  (unsigned long int) yystacksize));

      if (yyss + yystacksize - 1 <= yyssp)
        YYABORT;
    }

  YYDPRINTF ((stderr, "Entering state %d\n", yystate));

  if (yystate == YYFINAL)
    YYACCEPT;

  goto yybackup;

/*-----------.
| yybackup.  |
`-----------*/
yybackup:

  /* Do appropriate processing given the current state.  Read a
     lookahead token if we need one and don't already have one.  */

  /* First try to decide what to do without reference to lookahead token.  */
  yyn = yypact[yystate];
  if (yypact_value_is_default (yyn))
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
  if (yychar == YYEMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token: "));
      yychar = yylex ();
    }

  if (yychar <= YYEOF)
    {
      yychar = yytoken = YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else
    {
      yytoken = YYTRANSLATE (yychar);
      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  yyn += yytoken;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yytable_value_is_error (yyn))
        goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  /* Shift the lookahead token.  */
  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);

  /* Discard the shifted token.  */
  yychar = YYEMPTY;

  yystate = yyn;
  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END

  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- Do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     '$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];


  YY_REDUCE_PRINT (yyn);
  switch (yyn)
    {
        case 26:
#line 183 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { SetDPI((yyvsp[-1].sVal)); free((yyvsp[-1].sVal)); }
#line 1489 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 27:
#line 186 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { SetXKBLayout((yyvsp[-1].sVal)); }
#line 1495 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 28:
#line 189 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { SetXKBModel((yyvsp[-1].sVal)); }
#line 1501 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 29:
#line 192 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { SetXKBOptions((yyvsp[-1].sVal)); }
#line 1507 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 30:
#line 195 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { SetXKBRules((yyvsp[-1].sVal)); }
#line 1513 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 31:
#line 198 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { SetXKBVariant((yyvsp[-1].sVal)); }
#line 1519 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 32:
#line 201 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { SetTrayIcon((yyvsp[-1].sVal)); free((yyvsp[-1].sVal)); }
#line 1525 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 33:
#line 204 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { SetRootMenu((yyvsp[-1].sVal)); free((yyvsp[-1].sVal)); }
#line 1531 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 34:
#line 207 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { SetDefaultSysMenu((yyvsp[-2].sVal), (yyvsp[-1].iVal)); free((yyvsp[-2].sVal)); }
#line 1537 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 35:
#line 210 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { SetDefaultIcon((yyvsp[-1].sVal)); free((yyvsp[-1].sVal)); }
#line 1543 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 36:
#line 213 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { SetIconDirectory((yyvsp[-1].sVal)); free((yyvsp[-1].sVal)); }
#line 1549 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 37:
#line 216 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { AddMenuLine("-", CMD_SEPARATOR, ""); }
#line 1555 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 38:
#line 217 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { AddMenuLine((yyvsp[-3].sVal), CMD_ALWAYSONTOP, ""); free((yyvsp[-3].sVal)); }
#line 1561 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 39:
#line 218 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { AddMenuLine((yyvsp[-4].sVal), CMD_EXEC, (yyvsp[-2].sVal)); free((yyvsp[-4].sVal)); free((yyvsp[-2].sVal)); }
#line 1567 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 40:
#line 219 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { AddMenuLine((yyvsp[-4].sVal), CMD_MENU, (yyvsp[-2].sVal)); free((yyvsp[-4].sVal)); free((yyvsp[-2].sVal)); }
#line 1573 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 41:
#line 220 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { AddMenuLine((yyvsp[-3].sVal), CMD_RELOAD, ""); free((yyvsp[-3].sVal)); }
#line 1579 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 44:
#line 227 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { OpenMenu((yyvsp[-1].sVal)); free((yyvsp[-1].sVal)); }
#line 1585 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 45:
#line 227 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    {CloseMenu();}
#line 1591 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 46:
#line 230 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { AddIconLine((yyvsp[-3].sVal), (yyvsp[-2].sVal)); free((yyvsp[-3].sVal)); free((yyvsp[-2].sVal)); }
#line 1597 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 49:
#line 237 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    {OpenIcons();}
#line 1603 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 50:
#line 237 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    {CloseIcons();}
#line 1609 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 51:
#line 240 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { (yyval.uVal)=STYLE_TOPMOST; }
#line 1615 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 52:
#line 241 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { (yyval.uVal)=STYLE_MAXIMIZE; }
#line 1621 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 53:
#line 242 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { (yyval.uVal)=STYLE_MINIMIZE; }
#line 1627 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 54:
#line 243 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { (yyval.uVal)=STYLE_BOTTOM; }
#line 1633 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 55:
#line 246 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { (yyval.uVal)=STYLE_NOTITLE; }
#line 1639 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 56:
#line 247 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { (yyval.uVal)=STYLE_OUTLINE; }
#line 1645 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 57:
#line 248 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { (yyval.uVal)=STYLE_NOFRAME; }
#line 1651 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 58:
#line 251 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { (yyval.uVal)=STYLE_SKIPTASKBAR; }
#line 1657 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 59:
#line 254 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { (yyval.uVal)=(yyvsp[0].uVal); }
#line 1663 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 60:
#line 255 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { (yyval.uVal)=(yyvsp[0].uVal); }
#line 1669 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 61:
#line 256 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { (yyval.uVal)=(yyvsp[0].uVal); }
#line 1675 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 62:
#line 257 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { (yyval.uVal)=(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
#line 1681 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 63:
#line 258 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { (yyval.uVal)=(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
#line 1687 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 64:
#line 259 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { (yyval.uVal)=(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
#line 1693 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 65:
#line 260 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { (yyval.uVal)=(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
#line 1699 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 66:
#line 261 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { (yyval.uVal)=(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
#line 1705 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 67:
#line 262 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { (yyval.uVal)=(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
#line 1711 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 68:
#line 263 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { (yyval.uVal)=(yyvsp[-2].uVal)|(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
#line 1717 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 69:
#line 264 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { (yyval.uVal)=(yyvsp[-2].uVal)|(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
#line 1723 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 70:
#line 265 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { (yyval.uVal)=(yyvsp[-2].uVal)|(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
#line 1729 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 71:
#line 266 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { (yyval.uVal)=(yyvsp[-2].uVal)|(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
#line 1735 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 72:
#line 267 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { (yyval.uVal)=(yyvsp[-2].uVal)|(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
#line 1741 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 73:
#line 268 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { (yyval.uVal)=(yyvsp[-2].uVal)|(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
#line 1747 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 74:
#line 271 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { AddStyleLine((yyvsp[-3].sVal), (yyvsp[-2].uVal)); free((yyvsp[-3].sVal)); }
#line 1753 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 77:
#line 278 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    {OpenStyles();}
#line 1759 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 78:
#line 278 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    {CloseStyles();}
#line 1765 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 79:
#line 281 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { (yyval.iVal)=AT_END; }
#line 1771 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 80:
#line 282 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { (yyval.iVal)=AT_START; }
#line 1777 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 81:
#line 283 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { (yyval.iVal)=AT_END; }
#line 1783 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 82:
#line 286 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { AddSysMenuLine((yyvsp[-4].sVal), (yyvsp[-3].sVal), (yyvsp[-2].iVal)); free((yyvsp[-4].sVal)); free((yyvsp[-3].sVal)); }
#line 1789 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 85:
#line 293 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    {OpenSysMenu();}
#line 1795 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 86:
#line 293 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    {CloseSysMenu();}
#line 1801 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 87:
#line 296 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { pref.fForceExit = TRUE; }
#line 1807 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 88:
#line 299 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { pref.fSilentExit = TRUE; }
#line 1813 "winprefsyacc.c" /* yacc.c:1646  */
    break;

  case 89:
#line 302 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
    { ErrorF("LoadPreferences: %s\n", (yyvsp[-1].sVal)); free((yyvsp[-1].sVal)); }
#line 1819 "winprefsyacc.c" /* yacc.c:1646  */
    break;


#line 1823 "winprefsyacc.c" /* yacc.c:1646  */
      default: break;
    }
  /* User semantic actions sometimes alter yychar, and that requires
     that yytoken be updated with the new translation.  We take the
     approach of translating immediately before every use of yytoken.
     One alternative is translating here after every semantic action,
     but that translation would be missed if the semantic action invokes
     YYABORT, YYACCEPT, or YYERROR immediately after altering yychar or
     if it invokes YYBACKUP.  In the case of YYABORT or YYACCEPT, an
     incorrect destructor might then be invoked immediately.  In the
     case of YYERROR or YYBACKUP, subsequent parser actions might lead
     to an incorrect destructor call or verbose syntax error message
     before the lookahead is translated.  */
  YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);

  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);

  *++yyvsp = yyval;

  /* Now 'shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */

  yyn = yyr1[yyn];

  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
    yystate = yytable[yystate];
  else
    yystate = yydefgoto[yyn - YYNTOKENS];

  goto yynewstate;


/*--------------------------------------.
| yyerrlab -- here on detecting error.  |
`--------------------------------------*/
yyerrlab:
  /* Make sure we have latest lookahead translation.  See comments at
     user semantic actions for why this is necessary.  */
  yytoken = yychar == YYEMPTY ? YYEMPTY : YYTRANSLATE (yychar);

  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
#if ! YYERROR_VERBOSE
      yyerror (YY_("syntax error"));
#else
# define YYSYNTAX_ERROR yysyntax_error (&yymsg_alloc, &yymsg, \
                                        yyssp, yytoken)
      {
        char const *yymsgp = YY_("syntax error");
        int yysyntax_error_status;
        yysyntax_error_status = YYSYNTAX_ERROR;
        if (yysyntax_error_status == 0)
          yymsgp = yymsg;
        else if (yysyntax_error_status == 1)
          {
            if (yymsg != yymsgbuf)
              YYSTACK_FREE (yymsg);
            yymsg = (char *) YYSTACK_ALLOC (yymsg_alloc);
            if (!yymsg)
              {
                yymsg = yymsgbuf;
                yymsg_alloc = sizeof yymsgbuf;
                yysyntax_error_status = 2;
              }
            else
              {
                yysyntax_error_status = YYSYNTAX_ERROR;
                yymsgp = yymsg;
              }
          }
        yyerror (yymsgp);
        if (yysyntax_error_status == 2)
          goto yyexhaustedlab;
      }
# undef YYSYNTAX_ERROR
#endif
    }



  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse lookahead token after an
         error, discard it.  */

      if (yychar <= YYEOF)
        {
          /* Return failure if at end of input.  */
          if (yychar == YYEOF)
            YYABORT;
        }
      else
        {
          yydestruct ("Error: discarding",
                      yytoken, &yylval);
          yychar = YYEMPTY;
        }
    }

  /* Else will try to reuse lookahead token after shifting the error
     token.  */
  goto yyerrlab1;


/*---------------------------------------------------.
| yyerrorlab -- error raised explicitly by YYERROR.  |
`---------------------------------------------------*/
yyerrorlab:

  /* Pacify compilers like GCC when the user code never invokes
     YYERROR and the label yyerrorlab therefore never appears in user
     code.  */
  if (/*CONSTCOND*/ 0)
     goto yyerrorlab;

  /* Do not reclaim the symbols of the rule whose action triggered
     this YYERROR.  */
  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);
  yystate = *yyssp;
  goto yyerrlab1;


/*-------------------------------------------------------------.
| yyerrlab1 -- common code for both syntax error and YYERROR.  |
`-------------------------------------------------------------*/
yyerrlab1:
  yyerrstatus = 3;      /* Each real token shifted decrements this.  */

  for (;;)
    {
      yyn = yypact[yystate];
      if (!yypact_value_is_default (yyn))
        {
          yyn += YYTERROR;
          if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYTERROR)
            {
              yyn = yytable[yyn];
              if (0 < yyn)
                break;
            }
        }

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
        YYABORT;


      yydestruct ("Error: popping",
                  yystos[yystate], yyvsp);
      YYPOPSTACK (1);
      yystate = *yyssp;
      YY_STACK_PRINT (yyss, yyssp);
    }

  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END


  /* Shift the error token.  */
  YY_SYMBOL_PRINT ("Shifting", yystos[yyn], yyvsp, yylsp);

  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturn;

/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturn;

#if !defined yyoverflow || YYERROR_VERBOSE
/*-------------------------------------------------.
| yyexhaustedlab -- memory exhaustion comes here.  |
`-------------------------------------------------*/
yyexhaustedlab:
  yyerror (YY_("memory exhausted"));
  yyresult = 2;
  /* Fall through.  */
#endif

yyreturn:
  if (yychar != YYEMPTY)
    {
      /* Make sure we have latest lookahead translation.  See comments at
         user semantic actions for why this is necessary.  */
      yytoken = YYTRANSLATE (yychar);
      yydestruct ("Cleanup: discarding lookahead",
                  yytoken, &yylval);
    }
  /* Do not reclaim the symbols of the rule whose action triggered
     this YYABORT or YYACCEPT.  */
  YYPOPSTACK (yylen);
  YY_STACK_PRINT (yyss, yyssp);
  while (yyssp != yyss)
    {
      yydestruct ("Cleanup: popping",
                  yystos[*yyssp], yyvsp);
      YYPOPSTACK (1);
    }
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif
#if YYERROR_VERBOSE
  if (yymsg != yymsgbuf)
    YYSTACK_FREE (yymsg);
#endif
  return yyresult;
}
#line 306 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1906  */

/*
 * Errors in parsing abort and print log messages
 */
static int
yyerror (const char *s)
{
  ErrorF("LoadPreferences: %s line %d\n", s, yylineno);
  return 1;
}

static void
SetDPI (char *dpi)
{
  if (!g_cmdline.customDPI)
    monitorResolution = atoi (dpi);
}

static void
SetXKBLayout (char *layout)
{
  if (!g_cmdline.xkbLayout)
    g_cmdline.xkbLayout = layout;
  else
    free (layout);
}

static void
SetXKBModel (char *model)
{
  if (!g_cmdline.xkbModel)
    g_cmdline.xkbModel = model;
  else
    free (model);
}

static void
SetXKBOptions (char *options)
{
  if (!g_cmdline.xkbOptions)
    g_cmdline.xkbOptions = options;
  else
    free (options);
}

static void
SetXKBRules (char *rules)
{
  if (!g_cmdline.xkbRules)
    g_cmdline.xkbRules = rules;
  else
    free (rules);
}

static void
SetXKBVariant (char *variant)
{
  if (!g_cmdline.xkbVariant)
    g_cmdline.xkbVariant = variant;
  else
    free (variant);
}

/* Miscellaneous functions to store TOKENs into the structure */
static void
SetIconDirectory (char *path)
{
  strncpy (pref.iconDirectory, path, PATH_MAX);
  pref.iconDirectory[PATH_MAX] = 0;
}

static void
SetDefaultIcon (char *fname)
{
  strncpy (pref.defaultIconName, fname, NAME_MAX);
  pref.defaultIconName[NAME_MAX] = 0;
}

static void
SetTrayIcon (char *fname)
{
  strncpy (pref.trayIconName, fname, NAME_MAX);
  pref.trayIconName[NAME_MAX] = 0;
}

static void
SetRootMenu (char *menuname)
{
  strncpy (pref.rootMenuName, menuname, MENU_MAX);
  pref.rootMenuName[MENU_MAX] = 0;
}

static void
SetDefaultSysMenu (char *menuname, int pos)
{
  strncpy (pref.defaultSysMenuName, menuname, MENU_MAX);
  pref.defaultSysMenuName[MENU_MAX] = 0;
  pref.defaultSysMenuPos = pos;
}

static void
OpenMenu (char *menuname)
{
  if (menu.menuItem) free(menu.menuItem);
  menu.menuItem = NULL;
  strncpy(menu.menuName, menuname, MENU_MAX);
  menu.menuName[MENU_MAX] = 0;
  menu.menuItems = 0;
}

static void
AddMenuLine (const char *text, MENUCOMMANDTYPE cmd, const char *param)
{
  if (menu.menuItem==NULL)
    menu.menuItem = malloc(sizeof(MENUITEM));
  else
    menu.menuItem = realloc(menu.menuItem, sizeof(MENUITEM)*(menu.menuItems+1));

  strncpy (menu.menuItem[menu.menuItems].text, text, MENU_MAX);
  menu.menuItem[menu.menuItems].text[MENU_MAX] = 0;

  menu.menuItem[menu.menuItems].cmd = cmd;

  strncpy(menu.menuItem[menu.menuItems].param, param, PARAM_MAX);
  menu.menuItem[menu.menuItems].param[PARAM_MAX] = 0;

  menu.menuItem[menu.menuItems].commandID = 0;

  menu.menuItems++;
}

static void
CloseMenu (void)
{
  if (menu.menuItem==NULL || menu.menuItems==0)
    {
      ErrorF("LoadPreferences: Empty menu detected\n");
      return;
    }
  
  if (pref.menuItems)
    pref.menu = realloc (pref.menu, (pref.menuItems+1)*sizeof(MENUPARSED));
  else
    pref.menu = malloc (sizeof(MENUPARSED));
  
  memcpy (pref.menu+pref.menuItems, &menu, sizeof(MENUPARSED));
  pref.menuItems++;

  memset (&menu, 0, sizeof(MENUPARSED));
}

static void 
OpenIcons (void)
{
  if (pref.icon != NULL) {
    ErrorF("LoadPreferences: Redefining icon mappings\n");
    free(pref.icon);
    pref.icon = NULL;
  }
  pref.iconItems = 0;
}

static void
AddIconLine (char *matchstr, char *iconfile)
{
  if (pref.icon==NULL)
    pref.icon = malloc(sizeof(ICONITEM));
  else
    pref.icon = realloc(pref.icon, sizeof(ICONITEM)*(pref.iconItems+1));

  strncpy(pref.icon[pref.iconItems].match, matchstr, MENU_MAX);
  pref.icon[pref.iconItems].match[MENU_MAX] = 0;

  strncpy(pref.icon[pref.iconItems].iconFile, iconfile, PATH_MAX+NAME_MAX+1);
  pref.icon[pref.iconItems].iconFile[PATH_MAX+NAME_MAX+1] = 0;

  pref.icon[pref.iconItems].hicon = 0;

  pref.iconItems++;
}

static void 
CloseIcons (void)
{
}

static void
OpenStyles (void)
{
  if (pref.style != NULL) {
    ErrorF("LoadPreferences: Redefining window style\n");
    free(pref.style);
    pref.style = NULL;
  }
  pref.styleItems = 0;
}

static void
AddStyleLine (char *matchstr, unsigned long style)
{
  if (pref.style==NULL)
    pref.style = malloc(sizeof(STYLEITEM));
  else
    pref.style = realloc(pref.style, sizeof(STYLEITEM)*(pref.styleItems+1));

  strncpy(pref.style[pref.styleItems].match, matchstr, MENU_MAX);
  pref.style[pref.styleItems].match[MENU_MAX] = 0;

  pref.style[pref.styleItems].type = style;

  pref.styleItems++;
}

static void
CloseStyles (void)
{
}

static void
OpenSysMenu (void)
{
  if (pref.sysMenu != NULL) {
    ErrorF("LoadPreferences: Redefining system menu\n");
    free(pref.sysMenu);
    pref.sysMenu = NULL;
  }
  pref.sysMenuItems = 0;
}

static void
AddSysMenuLine (char *matchstr, char *menuname, int pos)
{
  if (pref.sysMenu==NULL)
    pref.sysMenu = malloc(sizeof(SYSMENUITEM));
  else
    pref.sysMenu = realloc(pref.sysMenu, sizeof(SYSMENUITEM)*(pref.sysMenuItems+1));

  strncpy (pref.sysMenu[pref.sysMenuItems].match, matchstr, MENU_MAX);
  pref.sysMenu[pref.sysMenuItems].match[MENU_MAX] = 0;

  strncpy (pref.sysMenu[pref.sysMenuItems].menuName, menuname, MENU_MAX);
  pref.sysMenu[pref.sysMenuItems].menuName[MENU_MAX] = 0;

  pref.sysMenu[pref.sysMenuItems].menuPos = pos;

  pref.sysMenuItems++;
}

static void
CloseSysMenu (void)
{
}

